@@ -2,20 +2,22 @@ import logging
 
 from cryptojwt.exception import UnsupportedAlgorithm
 
+from oidcmsg.message import OPTIONAL_LIST_OF_SP_SEP_STRINGS
 from oidcmsg.time_util import utc_time_sans_frac
+
 from ..exception import MessageException
 from ..exception import NotForMe
-from ..message import Message
 from ..message import REQUIRED_LIST_OF_STRINGS
 from ..message import SINGLE_OPTIONAL_STRING
 from ..message import SINGLE_REQUIRED_INT
 from ..message import SINGLE_REQUIRED_JSON
 from ..message import SINGLE_REQUIRED_STRING
+from ..message import Message
 from ..oauth2 import ResponseMessage
 from ..oidc import ID_TOKEN_VERIFY_ARGS
+from ..oidc import SINGLE_OPTIONAL_IDTOKEN
 from ..oidc import IdToken
 from ..oidc import MessageWithIdToken
-from ..oidc import SINGLE_OPTIONAL_IDTOKEN
 from ..oidc import clear_verified_claims
 from ..oidc import verified_claim_name
 from ..oidc import verify_id_token
@@ -49,7 +51,8 @@ class EndSessionRequest(Message):
     c_param = {
         "id_token_hint": SINGLE_OPTIONAL_IDTOKEN,
         "post_logout_redirect_uri": SINGLE_OPTIONAL_STRING,
-        "state": SINGLE_OPTIONAL_STRING
+        "state": SINGLE_OPTIONAL_STRING,
+        "ui_locales": OPTIONAL_LIST_OF_SP_SEP_STRINGS
     }
 
     def verify(self, **kwargs):
